@@ -2,7 +2,7 @@
 # This file is part of pygal
 #
 # A python svg graph plotting library
-# Copyright © 2012-2015 Kozea
+# Copyright © 2012-2016 Kozea
 #
 # This library is free software: you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -16,12 +16,12 @@
 #
 # You should have received a copy of the GNU Lesser General Public License
 # along with pygal. If not, see <http://www.gnu.org/licenses/>.
-
 """Class holding state during render"""
 
+from pygal.util import merge
+
 
 class State(object):
-
     """
     Class containing config values
     overriden by chart values
@@ -30,7 +30,7 @@ class State(object):
 
     def __init__(self, graph, **kwargs):
         """Create the transient state"""
-        self.__dict__.update(**graph.config.__class__.__dict__)
-        self.__dict__.update(**graph.config.__dict__)
-        self.__dict__.update(**graph.__dict__)
-        self.__dict__.update(**kwargs)
+        merge(self.__dict__, graph.config.__class__.__dict__)
+        merge(self.__dict__, graph.config.__dict__)
+        merge(self.__dict__, graph.__dict__)
+        merge(self.__dict__, kwargs)
